import { get, post, put, del, getWithConfig } from './http'

let baseUrl = 'https://wms.compdf.com'
let backgroundUrl = 'https://api-backend.compdf.com'
if (process.env.VUE_APP_MODE_ENV !== 'production') {
  baseUrl = 'http://test-compdf.kdan.cn:3060'
  backgroundUrl = 'http://101.132.103.13:8088'
}
// 登录
export const apiLogin = (data: object, config: object) => post(baseUrl + '/api/user/login', data, config)
// 获取个人信息
export const getUserInfo = (params: object) => get(baseUrl + '/api/user/get-user-info', params)
// 登出
export const apiLoginOut = (params: object) => get(baseUrl + '/api/user/sign-out', params)
// 进度条 - 获取账户套餐余额
export const getPackageBalance = (params: object) => get('/user-api/v1/balance/getPackageBalance', params)
// 获取用户首次登录时间
export const getUserFirstLogin = (params: object) => get('/user-api/v1/user/userFirstLogin', params)

// Dashboard - 获取当前用户下所有project
export const getProjects = (params: object) => get('/user-api/v1/convert-data/getProjects', params)
// Dashboard - 获取工具列表
export const getTools = (params: object) => get('/user-api/v1/convert-data/getTools', params)
// Dashboard - 获取4个点统计信息
export const getAnalysisData = (params: object) => get('/user-api/v1/convert-data/getAnalysisData-byDay', params)
// Dashboard - 获取Echarts图表数据
export const getDetailedData = (index: number, params: object) => {
  if (index === 1) {
    return getSuccessfulRequestDetailedData(params)
  } else if (index === 2) {
    return getErrorRequestDetailedData(params)
  } else if (index === 3) {
    return getErrorRatioDetailedData(params)
  } else {
    return getAverageProcessTimeDetailedData(params)
  }
}
// Dashboard - 获取成功数时间节点数据集合 Successful Requests
const getSuccessfulRequestDetailedData = (params: object) => get('/user-api/v1/convert-data/getSuccessfulRequestDetailedData', params)
// Dashboard - 获取失败数量 Error Requests
const getErrorRequestDetailedData = (params: object) => get('/user-api/v1/convert-data/getErrorRequestDetailedData', params)
// Dashboard - 获取失败率 Error Ratio
const getErrorRatioDetailedData = (params: object) => get('/user-api/v1/convert-data/getErrorRatioDetailedData', params)
// Dashboard - 获取平均转换时间 Average Process Date
const getAverageProcessTimeDetailedData = (params: object) => get('/user-api/v1/convert-data/getAverageProcessTimeDetailedData', params)
// Dashboard - 导出报表
export const getExport = (params: object, config: object) => getWithConfig('/user-api/v1/convert-data/export', params, config)

// security - 修改密码
export const apiChangePassword = (data: object, config: object) => post(baseUrl + '/api/user/change-password', data, config)
export const apiChangeUserName = (data: object, config: object) => post(backgroundUrl + '/user-api/v1/user/updateName', data, config)

// API Keys - 获取列表
export const getProjectList = (params: object) => get('/user-api/v1/project/getProjectList', params)
// API Keys - 添加新项目
export const apiAddNewProject = (data: object, config: object) => post('/user-api/v1/project/addNewProject', data, config)
// API Keys - 删除项目
export const apiDeleteProject = (id: number) => del('/user-api/v1/project/deleteById/' + id)
// API Keys - 编辑项目
export const apiEditProject = (data: object, config: object) => put('/user-api/v1/project/editProject', data, config)

// webhooks - 获取webhooks列表
export const getWebhooksList = (params: object) => get('/user-api/v1/webhook/getWebhookList', params)
// webhooks - 添加新webhook
export const apiAddNewWebhook = (data: object, config: object) => post('/user-api/v1/webhook/addNewWebhook', data, config)
// webhooks - 删除webhook
export const apiDeleteWebhook = (id: object) => del('/user-api/v1/webhook/deleteById/' + id)
// webhooks - 编辑webhook
export const apiEditWebhook = (data: object, config: object) => put('/user-api/v1/webhook/editWebhook', data, config)
// webhooks - 编辑Webhook时，查询已勾选事件id
export const getEnableEventIdList = (webhookId: string, params: object) => get('/user-api/v1/webhook/getEnableEventIdList/' + webhookId, params)
// webhooks - 获取系统事件，新增编辑Webhook页面调用
export const getEventList = (params: object) => get('/user-api/v1/webhook/getEventList', params)
// webhooks - 获取Webhook信息，新增编辑Webhook页面调用
export const getWebhookInfo = (webhookId: string, params: object) => get('/user-api/v1/webhook/getWebhookInfoById/' + webhookId, params)
// webhooks - 修改webhook状态
export const editWebhookStatus = (data: object, config: object) => put('/user-api/v1/webhook/editWebhookStatus', data, config)

// plan - 获取账户套餐余额
export const getBalanceRecordList = (params: object) => get('/user-api/v1/balance/getBalanceRecordList', params)
// plan - 账户消费充值记录导出
export const exportBalanceRecordList = (params: object, config: object) => getWithConfig('/user-api/v1/balance/exportBalanceRecordList', params, config)
// plan - 套餐详情
export const getPricingPlanList = () => get('/user-api/v1/balance/getBill', {})
// 获取账单信息
export const getBillingInformation = () => get('/user-api/v1/user/billing/info', {})
// 获取账单信息
export const getInvoices = () => get('/user-api/v1/user/billing/getOrderBillVos', {})
// 更新账单信息
export const apiChangeInformation = (data: object, config: object) => post(backgroundUrl + '/user-api/v1/user/billing/update', data, config)
// 更新账单邮箱
export const apiChangeEmail = (data: object, config: object) => post(backgroundUrl + '/user-api/v1/user/billing/update/email', data, config)
// 申请开发票
export const apiApplyInvoice = (data: object, config: object) => post(backgroundUrl + '/user-api/v1/user/billing/applyInvoice', data, config)
// 发送邮件
export const apiSendEmail = (data: object, config: object) => post(backgroundUrl + '/user-api/v1/user/billing/billSendEmail', data, config)
