import Vue from 'vue'
import VueRouter, { RouteConfig } from 'vue-router'
import { loginStore } from '@/store/loginStore'
import pinia from '@/store/index'
import dashboard from '@/views/projects/dashboard.vue'
import login from '@/views/login.vue'
import security from '@/views/accountSettings/security.vue'
import apiKeys from '@/views/projects/api/apiKeys.vue'
import addApiKeys from '@/views/projects/api/add.vue'
import editApiKeys from '@/views/projects/api/edit.vue'
import webhooks from '@/views/projects/user/webhooks.vue'
import addWebhook from '@/views/projects/user/add.vue'
import editWebhook from '@/views/projects/user/edit.vue'
import plan from '@/views/billing/plan.vue'
import information from '@/views/billing/information.vue'
import invoices from '@/views/billing/invoices.vue'

Vue.use(VueRouter)

const routes: Array<RouteConfig> = [
  {
    path: '/',
    redirect: '/dashboard'
  },
  {
    path: '/dashboard',
    name: 'home',
    component: dashboard,
    meta: {
      title: 'Dashboard | ComPDFKit API for Developers'
    }
  },
  {
    path: '/login',
    name: 'login',
    component: login,
    meta: {
      title: 'Login in to ComPDFKit API for Developers'
    }
  },
  {
    path: '/user/password',
    name: 'security',
    component: security,
    meta: {
      title: 'Security | ComPDFKit API for Developers'
    }
  },
  {
    path: '/api/keys',
    name: 'apiKeys',
    component: apiKeys,
    children: [
      {
        path: 'new-project',
        name: 'addApiKeys',
        component: addApiKeys,
        meta: {
          showFather: false,
          title: 'API Keys | ComPDFKit API for Developers'
        }
      },
      {
        path: 'edit-project/:id',
        name: 'editApiKeys',
        component: editApiKeys,
        meta: {
          showFather: false,
          title: 'API Keys | ComPDFKit API for Developers'
        }
      }
    ],
    meta: {
      showFather: true,
      title: 'API Keys | ComPDFKit API for Developers'
    }
  },
  {
    path: '/user/webhooks',
    name: 'webhooks',
    component: webhooks,
    children: [
      {
        path: 'new-webhook',
        name: 'addWebhook',
        component: addWebhook,
        meta: {
          showFather: false,
          title: 'Webhooks | ComPDFKit API for Developers'
        }
      },
      {
        path: 'edit-webhook/:id',
        name: 'editWebhook',
        component: editWebhook,
        meta: {
          showFather: false,
          title: 'Webhooks | ComPDFKit API for Developers'
        }
      }
    ],
    meta: {
      showFather: true,
      title: 'Webhooks | ComPDFKit API for Developers'
    }
  },
  {
    path: '/billing/plan',
    name: 'plan',
    component: plan,
    meta: {
      title: 'Plan | ComPDFKit API for Developers'
    }
  },
  {
    path: '/billing/information',
    name: 'information',
    component: information,
    meta: {
      showFather: false,
      title: 'Billing Information | ComPDFKit API for Developers'
    }
  },
  {
    path: '/billing/invoices',
    name: 'invoices',
    component: invoices,
    meta: {
      showFather: false,
      title: 'Invoices Center | ComPDFKit API for Developers'
    }
  }
]

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes
})

// 是否登录，未登录跳转登录页
router.beforeEach((to, from, next) => {
  const user = loginStore().user
  if (user) {
    next()
  } else {
    const url = window.location.href
    window.location.href = process.env.VUE_APP_PDFSdk_DOMAIN + '/login?from=api&redirect=' + url
  }
})

// 设置title
router.afterEach(to => {
  if (to && to.meta && to.meta.title) {
    document.title = to.meta.title
  }
})

export default router
