import { defineStore } from 'pinia'
import Cookie from 'js-cookie'

const rawUser = Cookie.get('user')
const user = rawUser && JSON.parse(rawUser)

export const loginStore = defineStore('login', {
  state: () => ({
    isAuthenticated: false,
    token: (user && user.access_token) || '',
    user: user || null
  }),
  getters: {
    getAuthenticated: (state) => state.isAuthenticated,
    getUser: (state) => state.user
  },
  actions: {
    // 修改当前登录的状态
    setAuth (isAuth: boolean) {
      if (isAuth) {
        this.isAuthenticated = true
      } else {
        this.isAuthenticated = false
      }
      localStorage.setItem('isAuth', String(this.isAuthenticated))
    },
    // 设置token
    setToken (token: any) {
      this.token = token
      Cookie.set('access_token', this.token, { expires: 14 })
    },
    // 获取用户信息
    setUser (user: any) {
      if (user) {
        this.user = user
        Cookie.set('user', JSON.stringify(user), { expires: 14 })
      } else {
        this.user = {
          name: ''
        }
      }
    },
    // 清除token
    clearToken () {
      this.token = ''
      this.user = null
      Cookie.remove('access_token')
      Cookie.remove('user')
    }
  }
})
